
#include "MSS552.h"

//Vyhradena pamat pre IECM program
char data restrict1[0x10] _at_ 0x30;

//Tabulka znakov displeja
const char code disp_tab[] = {0xD7, 0x84, 0xE3, 0xE6, 0xB4, 0x76, 0x77, 0xC4, 0xF7, 0xF6};

//Premenne pre pracu s displejom
unsigned char segment, disp[5] = {0xD7, 0xD7, 0xD7, 0xD7, 0x00};

/**
	* @brief 		cakacia funkcia
	* @param 		parameter udava cas cakania v milisekundach. Cas nie je uplne presny!!!
	* @retval		bez navratovej hodnoty
	*/
void DelayMs(unsigned int ms)
{
	unsigned char n = 0;
	ms *= 4;
	for (ms; ms > 0; ms--)
	{
		n = 0x80; 																
		while(n) n--;
	}
}

/**
	* @brief 		inicializovanie casovaca 0 a zapnutie prerusenia
	* @param 		bez parametra
	* @retval		bez navratovej hodnoty
	*/
void Timer0_Init(void)
{
	TMOD &= 0xF0;
	TMOD |= 0x01;	
	ET0 = 1;
	TR0 = 1;
}


/**
	* @brief 		inicializuje seriovu linku s PC na prenosovu rychlost 9600BAUD
	* @param 		bez parametra
	* @retval		bez navratovej hodnoty
	*/
void UART_Init(void)
{
	ES0 = 0;				//zakazanie prerusenia od seriovej linky
	TMOD &= 0x0F;		//nastavenie casovaca 1 na mod2 - 8 bitovy so samonaplnanim
	TMOD |= 0x20;
	TH1 = 0xFC;			//nastavenie samonaplnacieho registra casovaca 1 na prenosovu rychlost 9600BAUD
	S0CON = 0x50; 	//seriova linka asynchronna 8-bitov, povolenie prijimania dat
	PCON &= 0x7F;		//vynuluje bit 8 kvoli nastaveniu prenosovej rychlosti
	TR1 = 1;				//povolenie casovaca 1
	TI = 1;
}

/**
	* @brief 		nacitanie hodnot z analogovych vstupov JM
	* @param 		num: kanal z ktoreho sa ma hodnota nacitat
	*		@arg		0: pravy potenciometer
	*		@arg		1: lavy potenciometer
	*		@arg		2: NTC teplotne cidlo
	* @retval		bez navratovej hodnoty
	*/
unsigned int AD_Read(char ch)
{
	int result;
	ADCON = 0x00;
	ADCON = 0x08 + ch;
	while(!(ADCON & 0x10));
	result = ADCH;
	return result;
}

/**
	* @brief 		inicializuje obvod ktory sa stara o zobrazovanie displeja
	* @param 		bez parametra
	* @retval		bez navratovej hodnoty
	*/
void Disp_Init(void)
{
	XBYTE[0x8100]=0x02;
}

/**
	* @brief 		prevod 16-bitoveho cisla na znaky displeja
	* @param 		num: cislo ktore sa ma previest
	* @retval		bez navratovej hodnoty
	*/
void Disp_Int(int num)
{
	disp[0] = disp_tab[(num / 1000) % 10];
	disp[1] = disp_tab[(num / 100) % 10];
	disp[2] = disp_tab[(num / 10) % 10];
	disp[3] = disp_tab[num % 10];
}

/**
	* @brief 		obsluzna rutina pre zobrazenie hodnoty na 7-seg displeji
	* @note			funkcia sa musi volat minimalne 125 krat za sekundu aby nebolo viditelne blikanie
	* @param 		bez parametrov
	* @retval		bez navratovej hodnoty
	*/
void Disp_Handle(void)
{
	segment ++;
	if(segment > 5) segment = 1;
	P4 = 0x00;
	XBYTE[0x8102] = segment * 0x20;
	P4 = disp[segment - 1];
}

/**
	* @brief 		zapnutie LED pri displeji 
	* @param 		LED: hodnota pre zapnutie jednotlivych LED
	* @retval		bez navratovej hodnoty
	*/
void Disp_LED(unsigned char LED)
{
	ACC = LED;
	F0 = ACC4;
	ACC4 = ACC7;
	ACC4 = ACC7;
	ACC7 = ACC5;
	ACC5 = F0;
	disp[4] = ACC;
}
